menu
convex_bottom_app_bar package
documentation
convex_body.dart
convex_body.dart
dark_mode
light_mode
convex_body
library
Classes
ConvexBody
A widget that displays a stack of children, showing only the child at the current index provided by the
ConvexTabController
. The stack updates when the controller notifies listeners.
convex_bottom_app_bar package
documentation
convex_body.dart
convex_bottom_app_bar
package
Libraries
bottom_curved_painter
centered_elastic_curve
convex_body
convex_bottom_app_bar
convex_bottom_app_bar_item
convex_bottom_app_bar_v2
convex_item
convex_tab_controller
convex_tab_view
convex_body library