centered_elastic_curve library
Classes
- CenteredElasticInCurve
- A custom curve that creates an elastic in animation centered around 0.5.
- CenteredElasticOutCurve
- A custom curve that creates an elastic out animation centered around 0.5.
- LinearPointCurve
- A custom curve that linearly interpolates between two points.